@@ -1,11 +1,13 @@
-from typing import Union
 
 from scipy.stats.qmc import Sobol
 from scipy.interpolate import interp1d
 
 
-from flex_optimization.problem_statement import ActiveMethod, Problem, StopCriteria, \
-    ContinuousVariable, DiscreteVariable
+from flex_optimization.core.recorder import Recorder
+from flex_optimization.core.variable import ContinuousVariable, DiscreteVariable
+from flex_optimization.core.problem import Problem
+from flex_optimization.core.method_subclass import ActiveMethod, StopCriteria
+from flex_optimization.methods import MethodClassification, MethodType
 
 
 def map_number(old_value, old_min, old_max, new_min, new_max) -> float:
@@ -15,12 +17,13 @@ def map_number(old_value, old_min, old_max, new_min, new_max) -> float:
 class MethodSobol(ActiveMethod):
 
     def __init__(self,
-             problem: Problem,
-             stop_criteria: Union[StopCriteria, list[StopCriteria]],
-             multiprocess: Union[bool, int] = False, **kwargs):
+                 problem: Problem,
+                 stop_criteria: StopCriteria | list[StopCriteria] | list[list[StopCriteria]],
+                 multiprocess: bool | int = False,
+                 recorder: Recorder = None):
 
         self.sobol = Sobol(d=len(problem.variables))
-        super().__init__(problem, stop_criteria, multiprocess)
+        super().__init__(problem, stop_criteria, multiprocess, recorder)
 
     def get_point(self) -> list:
         var = self.sobol.random()[0]
@@ -34,3 +37,10 @@ class MethodSobol(ActiveMethod):
                 raise NotImplementedError
 
         return out
+
+
+method_class = MethodClassification(
+    name="sobol",
+    func=MethodSobol,
+    type_=MethodType.ACTIVE_SAMPLING
+)
